@@ -31,4 +31,10 @@ from .config import Config
 with Config() as config:
     engine = sqlalchemy.create_engine(config["connection_string"])
 
+if engine.dialect.name == "postgresql":
+    engine.execute("""
+        CREATE EXTENSION IF NOT EXISTS
+            postgis;
+    """)
+
 Session = sqlalchemy.orm.sessionmaker(engine)
