@@ -31,11 +31,14 @@ __all__ = [
 ]
 
 
+import sqlalchemy
+
 from .conversation import Conversation
 from .hashtag import Hashtag
 from .language import Language
 from .mediaitem import MediaItem
 from .place import Place
+from .databaseschemaupdater import DatabaseSchemaUpdater
 from .tweet import Tweet
 from .url import Url
 from .user import User
@@ -43,4 +46,9 @@ from .user import User
 from ..engine import engine
 from .base import Base
 
+DATA_EXISTS = sqlalchemy.inspect(engine).has_table(Tweet.__table__)
+
 Base.metadata.create_all(engine)
+
+if DATA_EXISTS:
+    DatabaseSchemaUpdater().update_to_latest()
